unit AbstractStreams;

interface

type
  TARBWave = array of Word;
  TOStreamType = (ostUnknown, ostDO, ostAO);

var
  OStreamType: TOStreamType;
  
function QueryDevicePID(DI: LongWord; var PID: LongWord): LongWord;
function OStreamTypeOfKnownCard(PID: Word): TOStreamType;
procedure EnableWrite(DI: LongWord);
procedure OpenWriteAtFreq(DI: LongWord; WriteClockHz: Double);
procedure CloseWrite(DI: LongWord);
procedure WriteFrame(DI: LongWord; const StreamWave: TARBWave);
procedure ResetChip(DI: LongWord);



implementation

uses
  AIOUSB;

function QueryDevicePID(DI: LongWord; var PID: LongWord): LongWord;
begin
  Result := QueryDeviceInfo(DI, @PID, nil, nil, nil, nil);
end;

function OStreamTypeOfKnownCard(PID: Word): TOStreamType;
begin
  case PID of
    $800C..$800F: Result := ostDO;
    $8068: Result := ostAO;
    else Result := ostUnknown;
  end;
end;

procedure EnableWrite(DI: LongWord);
var
  OutMask: Byte;
  MedDIOData: LongWord;

begin
  case OStreamType of
    ostDO: begin
      OutMask := $8;
      MedDIOData := $FFFFFFFF;
      DIO_StreamOpen(DI, False);
      DIO_StreamClose(DI);
      DIO_Configure(DI, False, @OutMask, @MedDIOData);
    end;
    ostAO: DACSetBoardRange(DI, 0);
  end;
end;

procedure OpenWriteAtFreq(DI: LongWord; WriteClockHz: Double);
var
  ReadClockHz: Double;

begin
  case OStreamType of
    ostDO: begin
      DIO_StreamOpen(DI, False);
      ReadClockHz := 0;
      DIO_StreamSetClocks(DI, ReadClockHz, WriteClockHz);
    end;
    ostAO: DACOutputOpen(DI, WriteClockHz);
  end;
end;

procedure CloseWrite(DI: LongWord);
begin
  case OStreamType of
    ostDO: DIO_StreamClose(DI);
    ostAO: DACOutputClose(DI, True);
  end;
end;

procedure WriteFrame(DI: LongWord; const StreamWave: TARBWave);
var
  BytesTransferred: LongWord;

begin
  case OStreamType of
    ostDO: DIO_StreamFrame(DI, Length(StreamWave), @StreamWave[0], BytesTransferred);
    ostAO: DACOutputFrameRaw(DI, Length(StreamWave), @StreamWave[0]);
  end;
end;

procedure ResetChip(DI: LongWord);
begin
  AIOUSB_ResetChip(DI);
end;

end.
